package com.zhyc.module.frozen.mapper;

import java.util.List;
import com.zhyc.module.frozen.domain.DdSale;
import com.zhyc.module.frozen.domain.DdSaleItem;
import org.apache.ibatis.annotations.Mapper;

/**
 * 销售主单Mapper接口
 * 
 * @author HashMap
 * @date 2025-12-01
 */
@Mapper
public interface DdSaleMapper 
{
    /**
     * 查询销售主单
     * 
     * @param id 销售主单主键
     * @return 销售主单
     */
    public DdSale selectDdSaleById(Long id);

    /**
     * 查询销售主单列表
     * 
     * @param ddSale 销售主单
     * @return 销售主单集合
     */
    public List<DdSale> selectDdSaleList(DdSale ddSale);

    /**
     * 新增销售主单
     * 
     * @param ddSale 销售主单
     * @return 结果
     */
    public int insertDdSale(DdSale ddSale);

    /**
     * 修改销售主单
     * 
     * @param ddSale 销售主单
     * @return 结果
     */
    public int updateDdSale(DdSale ddSale);

    /**
     * 删除销售主单
     * 
     * @param id 销售主单主键
     * @return 结果
     */
    public int deleteDdSaleById(Long id);

    /**
     * 批量删除销售主单
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDdSaleByIds(Long[] ids);

    /**
     * 批量删除销售明细
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDdSaleItemBySaleIds(Long[] ids);
    
    /**
     * 批量新增销售明细
     * 
     * @param ddSaleItemList 销售明细列表
     * @return 结果
     */
    public int batchDdSaleItem(List<DdSaleItem> ddSaleItemList);
    

    /**
     * 通过销售主单主键删除销售明细信息
     * 
     * @param id 销售主单ID
     * @return 结果
     */
    public int deleteDdSaleItemBySaleId(Long id);
}
